@@ -162,7 +162,7 @@ static const struct p_functions_hooks {
      "Won't enforce validation on 'generic_permission'",
      1
    },
-#ifdef CONFIG_SECURITY_SELINUX
+#ifdef CONFIG_SECURITY_SELINUX_DEVELOP
    { "sel_write_enforce",
      p_install_sel_write_enforce_hook,
      p_uninstall_sel_write_enforce_hook,
@@ -367,7 +367,7 @@ static void p_ed_wq_valid_cache_zero(void *p_arg) {
    memset(p_struct, 0, sizeof(struct work_struct));
 }
 
-int p_ed_wq_valid_cache_init(void) {
+static int p_ed_wq_valid_cache_init(void) {
 
    if ( (p_ed_wq_valid_cache = kmem_cache_create("p_ed_wq_valid_cache", sizeof(struct work_struct),
                                                  0, P_LKRG_CACHE_FLAGS, p_ed_wq_valid_cache_zero)) == NULL) {
@@ -379,7 +379,16 @@ int p_ed_wq_valid_cache_init(void) {
 
 static void p_ed_wq_valid_cache_delete(void) {
 
+#ifdef flush_workqueue
+/*
+ * When flush_workqueue became a macro, it started emitting warnings and the
+ * below function was introduced in place of the original function.  We should
+ * avoid flushing a system queue, but meanwhile we just suppress the warnings.
+ */
+   __flush_workqueue(system_unbound_wq);
+#else
    flush_workqueue(system_unbound_wq);
+#endif
    if (p_ed_wq_valid_cache) {
       kmem_cache_destroy(p_ed_wq_valid_cache);
       p_ed_wq_valid_cache = NULL;
@@ -424,7 +433,6 @@ static notrace void p_dump_creds(struct p_cred *p_where, const struct cred *p_fr
 #if defined(CONFIG_SECCOMP)
 static notrace void p_dump_seccomp(struct p_seccomp *p_sec, struct task_struct *p_task, char p_force) {
 
-   P_SYM(p_get_seccomp_filter)(p_task);
    p_sec->sec.mode    = p_task->seccomp.mode;   // Mode
    p_sec->sec.filter  = p_task->seccomp.filter; // Filter
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(5,11,0)
@@ -437,12 +445,6 @@ static notrace void p_dump_seccomp(struct p_seccomp *p_sec, struct task_struct *
       p_sec->flag = 0;
    if (p_force)
       p_sec->flag_sync_thread = 0;
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(5,9,0)
-   P_SYM(p_put_seccomp_filter)(p_task->seccomp.filter);
-#else
-   P_SYM(p_put_seccomp_filter)(p_task);
-#endif
-
 }
 #endif
 
@@ -1374,7 +1376,6 @@ static int p_cmp_tasks(struct p_ed_process *p_orig, struct task_struct *p_curren
 #if defined(CONFIG_SECCOMP)
    /* Seccomp */
    if (p_orig->p_ed_task.p_sec.flag) { // SECCOMP was enabled so it make sense to compare...
-      P_SYM(p_get_seccomp_filter)(p_current);
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(5,11,0)
       if (test_task_syscall_work(p_current,SECCOMP) != p_orig->p_ed_task.p_sec.flag) {
@@ -1406,13 +1407,8 @@ static int p_cmp_tasks(struct p_ed_process *p_orig, struct task_struct *p_curren
          p_ret++;
       }
 
-      P_CMP_PTR(p_orig->p_ed_task.p_sec.sec.filter, p_current->seccomp.filter, "seccomp filter")
-
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(5,9,0)
-      P_SYM(p_put_seccomp_filter)(p_current->seccomp.filter);
-#else
-      P_SYM(p_put_seccomp_filter)(p_current);
-#endif
+      if (current == p_current && !(p_current->flags & PF_EXITING))
+         P_CMP_PTR(p_orig->p_ed_task.p_sec.sec.filter, p_current->seccomp.filter, "seccomp filter")
    }
 #endif
 
@@ -1647,8 +1643,8 @@ int p_ed_enforce_pcfi(struct task_struct *p_task, struct p_ed_process *p_orig, s
    struct stack_frame p_frame;
 #endif
 #elif defined(CONFIG_ARM64)
-#  if (LINUX_VERSION_CODE >= KERNEL_VERSION(5,19,0)) \
-   || (RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(9,2))
+#  if LINUX_VERSION_CODE >= KERNEL_VERSION(5,19,0) || \
+   (defined(RHEL_RELEASE_CODE) && RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(9,2))
    struct unwind_state p_frame;
 #  else
    struct stackframe p_frame;
@@ -1669,6 +1665,9 @@ int p_ed_enforce_pcfi(struct task_struct *p_task, struct p_ed_process *p_orig, s
       p_sp_addr = p_regs_get_sp(p_regs);
 
    if (p_ed_pcfi_validate_sp(p_task,p_orig,p_sp_addr)) {
+#ifndef CONFIG_UNWINDER_ORC
+p_ed_enforce_pcfi_do:
+#endif
       // kill this process!
       p_pcfi_kill_task_by_task(p_task);
       p_not_valid = 1;
@@ -1688,8 +1687,9 @@ int p_ed_enforce_pcfi(struct task_struct *p_task, struct p_ed_process *p_orig, s
 
 #ifndef CONFIG_UNWINDER_ORC
    if (!p_is_obj_on_stack(p_task, p_fp)) {
-      p_print_log(P_LOG_FAULT, "Frame pointer is not on the stack, so CFI is not enforced");
-      goto p_ed_enforce_pcfi_out;
+      p_print_log(P_LOG_ALERT, "DETECT: Task: Frame pointer is not on the stack for pid %u, name %s",
+         task_pid_nr(p_task), p_task->comm);
+      goto p_ed_enforce_pcfi_do;
    }
 #endif
 
@@ -1979,15 +1979,6 @@ int p_exploit_detection_init(void) {
 
    P_SYM_INIT(__kernel_text_address)
    P_SYM_INIT(mm_find_pmd)
-#if defined(CONFIG_SECCOMP)
-   P_SYM_INIT(get_seccomp_filter)
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(5,9,0)
-#define p___put_seccomp_filter p_put_seccomp_filter
-   P_SYM_INIT(__put_seccomp_filter)
-#else
-   P_SYM_INIT(put_seccomp_filter)
-#endif
-#endif
 
 #ifdef CONFIG_SECURITY_SELINUX
 #if (!defined(RHEL_RELEASE_CODE) && LINUX_VERSION_CODE < KERNEL_VERSION(5, 6, 0)) || \
