@@ -19,7 +19,7 @@
  */
 
 #ifndef P_LKRG_EXPLOIT_DETECTION_SECURITY_PTRACE_ACCESS_H
-#define P_LKRG_EXPLOIT_DETECTION_SECURTIY_PTRACE_ACCESS_H
+#define P_LKRG_EXPLOIT_DETECTION_SECURITY_PTRACE_ACCESS_H
 
 struct p_security_ptrace_access_data {
     ktime_t entry_stamp;
