@@ -18,7 +18,7 @@
  *
  */
 
-#ifdef CONFIG_SECURITY_SELINUX
+#ifdef CONFIG_SECURITY_SELINUX_DEVELOP
 
 #ifndef P_LKRG_EXPLOIT_DETECTION_SEL_WRITE_ENFORCE_H
 #define P_LKRG_EXPLOIT_DETECTION_SEL_WRITE_ENFORCE_H
