@@ -30,7 +30,7 @@ int p_kmod_init(void) {
 #if defined(CONFIG_DYNAMIC_DEBUG)
    P_SYM_INIT(ddebug_tables)
    P_SYM_INIT(ddebug_lock)
- #if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 1, 0) && LINUX_VERSION_CODE < KERNEL_VERSION(6, 4, 0)
+ #if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 1, 0) && LINUX_VERSION_CODE < KERNEL_VERSION(6, 4, 0) && !defined(mod_mem_type_is_init)
    P_SYM_INIT(ddebug_remove_module)
  #endif
 #endif
@@ -38,7 +38,7 @@ int p_kmod_init(void) {
    P_SYM_INIT(modules)
    P_SYM_INIT(module_kset)
 
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(5,12,0)
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5,10,220)
    P_SYM_INIT(module_mutex)
    P_SYM_INIT(find_module)
 #else
@@ -50,7 +50,7 @@ int p_kmod_init(void) {
    p_debug_log(P_LOG_DEBUG, "<p_kmod_init> "
 #if defined(CONFIG_DYNAMIC_DEBUG)
                         "p_ddebug_tables[0x%lx] p_ddebug_lock[0x%lx] "
- #if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 1, 0) && LINUX_VERSION_CODE < KERNEL_VERSION(6, 4, 0)
+ #if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 1, 0) && LINUX_VERSION_CODE < KERNEL_VERSION(6, 4, 0) && !defined(mod_mem_type_is_init)
                         "p_ddebug_remove_module[0x%lx]"
  #endif
 #endif
@@ -59,7 +59,7 @@ int p_kmod_init(void) {
 #if defined(CONFIG_DYNAMIC_DEBUG)
                                                             (unsigned long)P_SYM(p_ddebug_tables),
                                                             (unsigned long)P_SYM(p_ddebug_lock),
- #if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 1, 0) && LINUX_VERSION_CODE < KERNEL_VERSION(6, 4, 0)
+ #if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 1, 0) && LINUX_VERSION_CODE < KERNEL_VERSION(6, 4, 0) && !defined(mod_mem_type_is_init)
                                                             (unsigned long)P_SYM(p_ddebug_remove_module),
  #endif
 #endif
@@ -164,7 +164,7 @@ static int p_list_from_module_list(p_module_list_mem *p_arg, char p_flag) {
 /*
  * 'module_mutex' must be taken by calling function!
  */
-unsigned int p_count_modules_from_sysfs_kobj(void) {
+static unsigned int p_count_modules_from_sysfs_kobj(void) {
 
    struct module *p_mod = NULL;
    struct kset *p_kset = *P_SYM(p_module_kset);
